Welcome to ClientVPS Mirrors

Help for package HGSL
Title: Heterogeneous Group Square-Root Lasso
Version: 1.0.0
Description: Estimation of high-dimensional multi-response regression with heterogeneous noises under Heterogeneous group square-root Lasso penalty. For details see: Ren, Z., Kang, Y., Fan, Y. and Lv, J. (2018)<doi:10.48550/arXiv.1606.03803>.
Depends: R (≥ 3.5.0)
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2018-08-31 02:30:38 UTC; Administrator
Author: Zhao Ren [aut], Yongjian Kang [aut, cre], Yingying Fan [aut], Jinchi Lv [aut]
Maintainer: Yongjian Kang <yongjiak@usc.edu>
Repository: CRAN
Date/Publication: 2018-08-31 08:30:10 UTC

S_TISP_Path Function

Description

This function allows you to obtain Estimation of high-dimensional multi-response regression with heterogeneous noises under eterogeneous group square-root Lasso penalty.

Usage

S_TISP_Path(X, y, grps, k, index, lambdas)

Arguments

X

A block diagonal design matrix.For each block, each row represents an observation. All blocks share the same number of columns.

y

response vector whose length equals to the sum of number of observations across all groups.

grps

a vector to indicate which group each entry of beta belongs

k

number of groups

index

a vector indicates the starting point and ending point for each group. For example, if there is 100 samples in the first group and 150 samples in the second group, then it is c(1,100,101,250)

lambdas

a vector of tuning parameters of group lasso penalty

Examples

p <- 10
n <- 20
k <- 2
X <- matrix(0, n*k, p*k)
X[1:n, 1:p] <- rnorm(n*p)
X[(n+1):(k*n), (p+1):(p*k)] <- rnorm(n*p)
beta <- c(0:9, (0:9)/2)
y <- X %*% beta + rnorm(n*k)*0.1
grps <- rep(1:p, k)
lambdas <- (1:5)/2
index <- c(1, n, n+1, 2*n)
betaest <- S_TISP_Path(X, y, grps, k, index, lambdas)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.